@@ -1,4 +1,6 @@
 x = [2, 3, 1]
+list(x)
 list(sorted(x))
 reversed(sorted(x))
+reversed(sorted(x, key=lambda e: e))
 reversed(sorted(x, reverse=True))
