@@ -1,3 +1,5 @@
+use std::ops::Deref;
+
 use rustpython_ast::{Arguments, Constant, Expr, ExprKind, Stmt, StmtKind};
 
 use crate::ast::types::Range;
@@ -11,7 +13,7 @@ use crate::{visibility, Check};
 
 #[derive(Default)]
 struct ReturnStatementVisitor<'a> {
-    returns: Vec<&'a Option<Box<Expr>>>,
+    returns: Vec<Option<&'a Expr>>,
 }
 
 impl<'a, 'b> Visitor<'b> for ReturnStatementVisitor<'a>
@@ -23,7 +25,9 @@ where
             StmtKind::FunctionDef { .. } | StmtKind::AsyncFunctionDef { .. } => {
                 // No recurse.
             }
-            StmtKind::Return { value } => self.returns.push(value),
+            StmtKind::Return { value } => {
+                self.returns.push(value.as_ref().map(|expr| expr.deref()))
+            }
             _ => visitor::walk_stmt(self, stmt),
         }
     }
@@ -49,10 +53,13 @@ fn is_none_returning(body: &[Stmt]) -> bool {
 }
 
 /// ANN401
-fn check_dynamically_typed(checker: &mut Checker, annotation: &Expr, name: &str) {
-    if checker.match_typing_module(annotation, "Any") {
+fn check_dynamically_typed<F>(checker: &mut Checker, annotation: &Expr, func: F)
+where
+    F: FnOnce() -> String,
+{
+    if checker.match_typing_expr(annotation, "Any") {
         checker.add_check(Check::new(
-            CheckKind::DynamicallyTypedExpression(name.to_string()),
+            CheckKind::DynamicallyTypedExpression(func()),
             Range::from_located(annotation),
         ));
     };
@@ -100,7 +107,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
             {
                 if let Some(expr) = &arg.node.annotation {
                     if checker.settings.enabled.contains(&CheckCode::ANN401) {
-                        check_dynamically_typed(checker, expr, &arg.node.arg);
+                        check_dynamically_typed(checker, expr, || arg.node.arg.to_string());
                     };
                 } else {
                     if !(checker.settings.flake8_annotations.suppress_dummy_args
@@ -122,7 +129,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
                     if !checker.settings.flake8_annotations.allow_star_arg_any {
                         if checker.settings.enabled.contains(&CheckCode::ANN401) {
                             let name = arg.node.arg.to_string();
-                            check_dynamically_typed(checker, expr, &format!("*{name}"));
+                            check_dynamically_typed(checker, expr, || format!("*{name}"));
                         }
                     }
                 } else {
@@ -145,7 +152,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
                     if !checker.settings.flake8_annotations.allow_star_arg_any {
                         if checker.settings.enabled.contains(&CheckCode::ANN401) {
                             let name = arg.node.arg.to_string();
-                            check_dynamically_typed(checker, expr, &format!("**{name}"));
+                            check_dynamically_typed(checker, expr, || format!("**{name}"));
                         }
                     }
                 } else {
@@ -165,7 +172,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
             // ANN201, ANN202, ANN401
             if let Some(expr) = &returns {
                 if checker.settings.enabled.contains(&CheckCode::ANN401) {
-                    check_dynamically_typed(checker, expr, name);
+                    check_dynamically_typed(checker, expr, || name.to_string());
                 };
             } else {
                 // Allow omission of return annotation in `__init__` functions, if the function
@@ -215,7 +222,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
                 if let Some(annotation) = &arg.node.annotation {
                     has_any_typed_arg = true;
                     if checker.settings.enabled.contains(&CheckCode::ANN401) {
-                        check_dynamically_typed(checker, annotation, &arg.node.arg);
+                        check_dynamically_typed(checker, annotation, || arg.node.arg.to_string());
                     }
                 } else {
                     if !(checker.settings.flake8_annotations.suppress_dummy_args
@@ -238,7 +245,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
                     if !checker.settings.flake8_annotations.allow_star_arg_any {
                         if checker.settings.enabled.contains(&CheckCode::ANN401) {
                             let name = arg.node.arg.to_string();
-                            check_dynamically_typed(checker, expr, &format!("*{name}"));
+                            check_dynamically_typed(checker, expr, || format!("*{name}"));
                         }
                     }
                 } else {
@@ -262,7 +269,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
                     if !checker.settings.flake8_annotations.allow_star_arg_any {
                         if checker.settings.enabled.contains(&CheckCode::ANN401) {
                             let name = arg.node.arg.to_string();
-                            check_dynamically_typed(checker, expr, &format!("**{name}"));
+                            check_dynamically_typed(checker, expr, || format!("**{name}"));
                         }
                     }
                 } else {
@@ -305,7 +312,7 @@ pub fn definition(checker: &mut Checker, definition: &Definition, visibility: &V
             // ANN201, ANN202
             if let Some(expr) = &returns {
                 if checker.settings.enabled.contains(&CheckCode::ANN401) {
-                    check_dynamically_typed(checker, expr, name);
+                    check_dynamically_typed(checker, expr, || name.to_string());
                 }
             } else {
                 // Allow omission of return annotation in `__init__` functions, if the function
