@@ -149,19 +149,26 @@ pub fn unnecessary_list_comprehension_set(
 
 /// C404 (`dict([...])`)
 pub fn unnecessary_list_comprehension_dict(
+    expr: &Expr,
     func: &Expr,
     args: &[Expr],
     keywords: &[Keyword],
+    locator: &SourceCodeLocator,
+    fix: bool,
     location: Range,
 ) -> Option<Check> {
     let argument = exactly_one_argument_with_matching_function("dict", func, args, keywords)?;
     if let ExprKind::ListComp { elt, .. } = &argument {
         match &elt.node {
             ExprKind::Tuple { elts, .. } if elts.len() == 2 => {
-                return Some(Check::new(
-                    CheckKind::UnnecessaryListComprehensionDict,
-                    location,
-                ));
+                let mut check = Check::new(CheckKind::UnnecessaryListComprehensionDict, location);
+                if fix {
+                    match fixes::fix_unnecessary_list_comprehension_dict(locator, expr) {
+                        Ok(fix) => check.amend(fix),
+                        Err(e) => error!("Failed to generate fix: {}", e),
+                    }
+                }
+                return Some(check);
             }
             _ => {}
         }
@@ -348,8 +355,11 @@ pub fn unnecessary_list_call(
 
 /// C413
 pub fn unnecessary_call_around_sorted(
+    expr: &Expr,
     func: &Expr,
     args: &[Expr],
+    locator: &SourceCodeLocator,
+    fix: bool,
     location: Range,
 ) -> Option<Check> {
     let outer = function_name(func)?;
@@ -358,10 +368,17 @@ pub fn unnecessary_call_around_sorted(
     }
     if let ExprKind::Call { func, .. } = &args.first()?.node {
         if function_name(func)? == "sorted" {
-            return Some(Check::new(
+            let mut check = Check::new(
                 CheckKind::UnnecessaryCallAroundSorted(outer.to_string()),
                 location,
-            ));
+            );
+            if fix {
+                match fixes::fix_unnecessary_call_around_sorted(locator, expr) {
+                    Ok(fix) => check.amend(fix),
+                    Err(e) => error!("Failed to generate fix: {}", e),
+                }
+            }
+            return Some(check);
         }
     }
     None
