@@ -1,7 +1,6 @@
 pub use deprecated_unittest_alias::deprecated_unittest_alias;
 pub use super_call_with_parameters::super_call_with_parameters;
 pub use type_of_primitive::type_of_primitive;
-pub use unnecessary_abspath::unnecessary_abspath;
 pub use unnecessary_encode_utf8::unnecessary_encode_utf8;
 pub use unnecessary_future_import::unnecessary_future_import;
 pub use unnecessary_lru_cache_params::unnecessary_lru_cache_params;
@@ -13,7 +12,6 @@ pub use useless_object_inheritance::useless_object_inheritance;
 mod deprecated_unittest_alias;
 mod super_call_with_parameters;
 mod type_of_primitive;
-mod unnecessary_abspath;
 mod unnecessary_encode_utf8;
 mod unnecessary_future_import;
 mod unnecessary_lru_cache_params;
