@@ -7,13 +7,14 @@ use crate::checks::{Check, CheckKind};
 
 /// U006
 pub fn use_pep585_annotation(checker: &mut Checker, expr: &Expr, id: &str) {
+    let replacement = checker.import_aliases.get(id).unwrap_or(&id);
     let mut check = Check::new(
-        CheckKind::UsePEP585Annotation(id.to_string()),
+        CheckKind::UsePEP585Annotation(replacement.to_string()),
         Range::from_located(expr),
     );
     if checker.patch() {
         check.amend(Fix::replacement(
-            id.to_lowercase(),
+            replacement.to_lowercase(),
             expr.location,
             expr.end_location.unwrap(),
         ));
