@@ -13,7 +13,9 @@ use crate::checks::CheckCode;
 use crate::checks_gen::{CheckCodePrefix, PrefixSpecificity};
 use crate::settings::configuration::Configuration;
 use crate::settings::types::{FilePattern, PerFileIgnore, PythonVersion};
-use crate::{flake8_annotations, flake8_bugbear, flake8_quotes, isort, pep8_naming};
+use crate::{
+    flake8_annotations, flake8_bugbear, flake8_quotes, flake8_tidy_imports, isort, pep8_naming,
+};
 
 pub mod configuration;
 pub mod options;
@@ -35,6 +37,7 @@ pub struct Settings {
     pub flake8_annotations: flake8_annotations::settings::Settings,
     pub flake8_bugbear: flake8_bugbear::settings::Settings,
     pub flake8_quotes: flake8_quotes::settings::Settings,
+    pub flake8_tidy_imports: flake8_tidy_imports::settings::Settings,
     pub isort: isort::settings::Settings,
     pub pep8_naming: pep8_naming::settings::Settings,
 }
@@ -54,6 +57,7 @@ impl Settings {
             flake8_annotations: config.flake8_annotations,
             flake8_bugbear: config.flake8_bugbear,
             flake8_quotes: config.flake8_quotes,
+            flake8_tidy_imports: config.flake8_tidy_imports,
             isort: config.isort,
             line_length: config.line_length,
             pep8_naming: config.pep8_naming,
@@ -76,6 +80,7 @@ impl Settings {
             flake8_annotations: Default::default(),
             flake8_bugbear: Default::default(),
             flake8_quotes: Default::default(),
+            flake8_tidy_imports: Default::default(),
             isort: Default::default(),
             pep8_naming: Default::default(),
         }
@@ -94,6 +99,7 @@ impl Settings {
             flake8_annotations: Default::default(),
             flake8_bugbear: Default::default(),
             flake8_quotes: Default::default(),
+            flake8_tidy_imports: Default::default(),
             isort: Default::default(),
             pep8_naming: Default::default(),
         }
