@@ -7,7 +7,9 @@ use regex::Regex;
 use crate::checks::CheckCode;
 use crate::checks_gen::CheckCodePrefix;
 use crate::settings::types::{FilePattern, PythonVersion};
-use crate::{flake8_annotations, flake8_quotes, isort, pep8_naming, Configuration};
+use crate::{
+    flake8_annotations, flake8_quotes, flake8_tidy_imports, isort, pep8_naming, Configuration,
+};
 
 /// Struct to render user-facing exclusion patterns.
 #[derive(Debug)]
@@ -50,6 +52,7 @@ pub struct UserConfiguration {
     // Plugins
     pub flake8_annotations: flake8_annotations::settings::Settings,
     pub flake8_quotes: flake8_quotes::settings::Settings,
+    pub flake8_tidy_imports: flake8_tidy_imports::settings::Settings,
     pub isort: isort::settings::Settings,
     pub pep8_naming: pep8_naming::settings::Settings,
     // Non-settings exposed to the user
@@ -95,6 +98,7 @@ impl UserConfiguration {
             target_version: configuration.target_version,
             flake8_annotations: configuration.flake8_annotations,
             flake8_quotes: configuration.flake8_quotes,
+            flake8_tidy_imports: configuration.flake8_tidy_imports,
             isort: configuration.isort,
             pep8_naming: configuration.pep8_naming,
             project_root,
